braindecode.datautil.exponential_moving_demean
==============================================

.. currentmodule:: braindecode.datautil

.. autofunction:: exponential_moving_demean

.. include:: braindecode.datautil.exponential_moving_demean.examples

.. raw:: html

    <div style='clear:both'></div>